@@ -194,7 +194,7 @@ class Downloader:
         redirected_url = href
         response = None
         try:
-            if proxy_use:
+            if not proxy_use:
                 response = requests.get(href, headers=headers, timeout=timeout)
             else:
                 response = requests.get(href, headers=headers, proxies=self.proxies, timeout=timeout)
@@ -246,7 +246,7 @@ class Downloader:
         redirected_url = href
         response = None
         try:
-            if proxy_use:
+            if not proxy_use:
                 response = requests.post(href, headers=headers, data=data, timeout=timeout)
             else:
                 response = requests.post(href, headers=headers, data=data, proxies=self.proxies, timeout=timeout)
